@@ -5,3 +5,5 @@ import pathlib
 sys.path.append(str(pathlib.Path(__file__).parent))
 __all__ = ["common_util", "crawler_util", "document_util", "office_util", "pdf_util"]
 
+from PaperCrawlerUtil.common_util import basic_config
+basic_config()
